import { Client, IChainEventArgs } from './client';
/**
 * Web3 provider that interacts with EVM contracts deployed on Loom DAppChains.
 */
export declare class LoomProvider {
    private _client;
    private _connection?;
    private _topicsList;
    private _deployedCodes;
    private _accounts;
    protected notificationCallbacks: Array<Function>;
    /**
     * @param client: The client which calls Ethereum EVM
     */
    constructor(client: Client);
    addAccounts(accounts: string | Array<string>): void;
    on(type: string, callback: any): void;
    addDefaultEvents(): void;
    removeListener(type: string, callback: (...args: any[]) => void): void;
    removeAllListeners(type: string, callback: Function): void;
    reset(): void;
    disconnect(): void;
    sendAsync(payload: any, callback: Function): Promise<void>;
    /**
     * Should be used to make async request
     * This method is used internally by web3, so we adapt it to be used with loom contract
     * when we are wrapping the evm on a DAppChain
     * @param payload JSON payload generated by web3 which will be translated to loom transaction/call
     * @param callback Triggered on end with (err, result)
     */
    send(payload: any, callback: Function): Promise<any>;
    private _deployAsync(payload);
    private _callAsync(payload);
    private _callStaticAsync(payload);
    private _getReceipt(txHash);
    protected _onWebSocketMessage(msgEvent: IChainEventArgs): void;
    protected _simulateEmptyBlock(block?: any): any;
    private _okResponse(id, result?, isArray?);
}
